@@ -1,5 +1,5 @@
 ### fit different models to each dose-response curve and choose the best fit 
-drcfit <- function(itemselect, sigmoid.model = c("Hill", "log-probit"), 
+drcfit <- function(itemselect,  
                    information.criterion = c("AICc", "BIC", "AIC"),
                    postfitfilter = TRUE,
                    progressbar = TRUE, 
@@ -25,7 +25,8 @@ drcfit <- function(itemselect, sigmoid.model = c("Hill", "log-probit"),
     cat("The fitting may be long if the number of selected items is high.\n")
   
   # Definition of the sigmoid model to fit
-  sigmoid.model <- match.arg(sigmoid.model, c("Hill", "log-probit"))
+  # sigmoid.model <- match.arg(sigmoid.model, c("Hill", "log-probit"))
+  sigmoid.model <- "Hill"
   
   # definition of necessary data
   selectindex <- itemselect$selectindex
@@ -837,7 +838,7 @@ plotfit2pdf <- function(x, items,
                   paste0("Figures are stored in ", normalizePath(path2figs), ".")))
   pdf(file2plot, width = 7, height = 10, onefile = TRUE) # w and h in inches
   
-  nplotsperpage = nrowperpage * ncolperpage
+  nplotsperpage <- nrowperpage * ncolperpage
   npage <- ceiling(nrow(subd) / nplotsperpage)
   
   for (i in 1:npage)
